<template>
    <div class="w-100">
        <MobileNumberChangeDialog
            v-if="user && !loading"
            :dialogTrigger="mobileChangeDialog"
            :mobile="user.mobile"
            @success="getUser"
        ></MobileNumberChangeDialog>
        <div class="_content text-xs-center" v-if="!loading">
            <v-form class="_main_form">
                <v-text-field
                    outline
                    name="firstname"
                    label="First Name"
                    v-model="user.firstname"
                    :rules="validateRules"
                ></v-text-field>
                <v-text-field
                    outline
                    name="lastname"
                    label="Last Name"
                    v-model="user.lastname"
                    :rules="validateRules"
                ></v-text-field>
                <v-text-field
                    outline
                    name="email"
                    label="Email"
                    v-model="user.email"
                    :rules="validateRules"
                ></v-text-field>
                <v-text-field
                    outline
                    name="mobile"
                    label="Mobile"
                    v-model="user.mobile"
                    :mask="phone"
                    disabled
                ></v-text-field>
                <div class="flex space-between">
                    <div></div>
                    <v-btn
                        class="mr-0 _change_mobile_button"
                        flat
                        @click="mobileChangeDialog = true"
                        color="secondary"
                    >Change</v-btn>
                </div>
                <v-text-field
                    outline
                    name="company"
                    label="Company Name"
                    v-model="user.company"
                ></v-text-field>
                <v-switch
                    false-value="0"
                    true-value="1"
                    color="success"
                    inset
                    v-model="user.enable_mail_notification"
                    label="E-Mail Notification"
                ></v-switch>
                <v-switch
                    false-value="0"
                    true-value="1"
                    color="success"
                    inset
                    v-model="user.enable_sms_notification"
                    label="SMS Notification"
                ></v-switch>
                <v-flex w-100 justify-end>
                    <v-btn
                        large
                        class="mr-0"
                        @click="updateUser"
                        :loading="bloading"
                        color="primary">
                        Update Profile
                    </v-btn>
                </v-flex>
            </v-form>
        </div>
        <div class="_content text-xs-center" v-else>
            <div class="content _progress">
                <v-progress-circular
                :width="3"
                :size="50"
                color="#525252"
                indeterminate
                ></v-progress-circular>
                <span>Loading profile..</span>
            </div>
        </div>
    </div>
</template>
<script>
import Vue from 'vue'
import axios from 'axios'
import MobileNumberChangeDialog from '~/components/MobileNumberChangeDialog'

Vue.component('MobileNumberChangeDialog', MobileNumberChangeDialog)

export default {
    layout: 'customer',
    data() {
        return {
            mobileChangeDialog: false,
            loading: true,
            bloading: false,
            user: [],
            validateRules: [
                v => !!v || 'This field is required'
            ],
            phone: 'phone',
        }
    },
    methods: {
        changeMobile () {
            alert('clicked');
        },
        updateUser() {
            this.bloading = true;
            var form_data = new FormData();
            form_data.append('firstname', this.user.firstname);
            form_data.append('lastname', this.user.lastname);
            form_data.append('company', this.user.company);
            form_data.append('enable_mail_notification', this.user.enable_mail_notification);
            form_data.append('enable_sms_notification', this.user.enable_sms_notification);
            axios.post(this.$store.state.api_domain + '?comp=process&action=updateUser', form_data, {
                withCredentials: true
            }).then((res) => {
                this.bloading = false;
                if (res.data.status == 'success') {
                    this.$store.commit('showSnackBar', res.data.message);
                    this.getUser();
                }
            });
        },
        getUser() {
            axios.get(this.$store.state.api_domain + '?comp=process&action=getUser', {
                withCredentials: true
            }).then((res) => {
                this.loading = false;
                this.user = res.data;
            });
        },
    },
    created() {
        this.getUser();
    },
    head () {
      return {
        title: 'Profile | Account | Cardboardbalingwire.com',
        meta: [
          { hid: 'description', name: 'description', content: 'User Profile' },
          { hid: 'keywords', name: 'keywords',  content: 'profile' }
        ]
      }
    }
}
</script>

<style>
    .v-btn._change_mobile_button {
    margin-top: -45px
    }
</style>
